/// <reference types="node" />
import { EventEmitter } from "events";
import { ValueOf } from "../utils";
import { Friend, Player, Room, Tribe } from "../structures";
import { languages } from "../enums";
import ClientEvents from "./Events";
interface ClientOptions {
    /**
     * Will try to auto reconnect when disconnected if set to true (Default: `true`)
     */
    autoReconnect?: boolean;
    language?: ValueOf<typeof languages>;
}
/**
 * Client interface for event intellisense support
 */
declare interface Client {
    /**
     * Listens to a Client Event
     */
    on<T extends keyof ClientEvents>(event: T, listener: ClientEvents[T]): this;
    /** @hidden */
    emit<T extends keyof ClientEvents>(event: T, ...args: Parameters<ClientEvents[T]>): boolean;
}
/**
 * Represents a client that connects to Transformice.
 *
 * @noInheritDoc
 */
declare class Client extends EventEmitter {
    private version;
    private connectionKey;
    private authClient;
    private authServer;
    private ports;
    private host;
    private tfmID;
    private token;
    private identificationKeys;
    private messageKeys;
    private main;
    private bulle;
    private loops;
    private tribulleID;
    private password;
    private autoReconnect;
    /**
     * The online players when the bot log.
     */
    onlinePlayers: number;
    /**
     * The client's room.
     */
    room: Room;
    /**
     * The client's player.
     */
    player: Player;
    /**
     * The client's ID.
     */
    playerID: number;
    /**
     * The client's name.
     */
    name: string;
    /**
     * The client's playing time.
     */
    playingTime: number;
    /**
     * The connection time.
     */
    connectionTime: number;
    /**
     * The client's community code.
     */
    community: number;
    /**
     * The language suggested by the server.
     */
    language: ValueOf<typeof languages>;
    /**
     * The client's temporary code.
     */
    pcode: number;
    constructor(name: string, password: string, options?: ClientOptions);
    /**
     *  Wait for specific event to be emitted
     */
    private waitFor;
    /**
     * Handles the old packets and emits events.
     */
    private handleOldPacket;
    /**
     * Handles the known packets and emits events.
     */
    private handlePacket;
    /**
     * Handles the community platform packets and emits events.
     */
    private handleTribulle;
    /**
     * Sends a packet to the community platform (tribulle).
     */
    private sendTribullePacket;
    /**
     * Sends a packet every 15 seconds to stay connected to the game.
     */
    private startHeartbeat;
    private sendHandshake;
    private setLanguage;
    private setSystemInfo;
    /**
     * Get Transformice API keys
     */
    private fetchKeys;
    /**
     * Log in to the game.
     */
    private login;
    /**
     * Connects and do handshake
     */
    private connect;
    /**
     * Disconnects the client.
     */
    disconnect(): void;
    /**
     * Starts the client
     */
    private start;
    /**
     * Starts the client.
     */
    run(tfmid: string, token: string): Promise<void>;
    /**
     * Restart the client
     */
    restart(): Promise<void>;
    /**
     * Sends a message to tribe
     */
    sendTribeMessage(message: string): void;
    /**
     * Joins the tribe house.
     */
    joinTribeHouse(): void;
    /**
     * Load a lua script in the room.
     */
    loadLua(script: string): void;
    /**
     * Join to a chat channel
     */
    joinChannel(channelName: string, permanent?: boolean): void;
    /**
     * Leave a chat channel
     */
    leaveChannel(channelName: string): void;
    /**
     * Sends a message to a chat channel
     */
    sendChannelMessage(channelName: string, message: string): void;
    /**
     * Sends a message to the client's room.
     */
    sendRoomMessage(message: string): void;
    /**
     * Sends a server command.
     *
     * @param message - The command message (without the `/`).
     * @example
     * ```js
     * client.sendCommand('mod');
     * ```
     */
    sendCommand(message: string): void;
    /**
     * Sends a request to the server to join a room with specific name.
     */
    joinRoom(name: string, isSalonAuto?: boolean): void;
    /**
     * Sends a whisper message to a player.
     */
    sendWhisper(name: string, message: string): void;
    /**
     * Request friend list.
     */
    requestFriendList(): void;
    /**
     * Get friend list
     */
    getFriendList(): Promise<Friend[]>;
    /**
     * Request tribe data
     */
    requestTribe(includeDisconnectedMember?: boolean): void;
    /**
     * Get tribe data
     */
    getTribe(includeDisconnectedMember?: boolean): Promise<Tribe | null>;
}
export default Client;
